@@ -1,17 +1,15 @@
-use 5.005;
 use strict;
-BEGIN{ if (not $] < 5.006) { require warnings; warnings->import } }
+use warnings;
 package File::pushd;
 # ABSTRACT: change directory temporarily for a limited scope
-our $VERSION = '1.001'; # VERSION
+our $VERSION = '1.005'; # VERSION
 
-use vars qw/@EXPORT @ISA/;
-@EXPORT  = qw( pushd tempd );
-@ISA     = qw( Exporter );
+our @EXPORT  = qw( pushd tempd );
+our @ISA     = qw( Exporter );
 
 use Exporter;
 use Carp;
-use Cwd         qw( cwd abs_path );
+use Cwd         qw( getcwd abs_path );
 use File::Path  qw( rmtree );
 use File::Temp  qw();
 use File::Spec;
@@ -28,7 +26,10 @@ sub pushd {
     my ($target_dir, $options) = @_;
     $options->{untaint_pattern} ||= qr{^([-+@\w./]+)$};
 
-    my $tainted_orig = cwd;
+    $target_dir = "." unless defined $target_dir;
+    croak "Can't locate directory $target_dir" unless -d $target_dir;
+
+    my $tainted_orig = getcwd;
     my $orig;
     if ( $tainted_orig =~ $options->{untaint_pattern} ) {
       $orig = $1;
@@ -39,6 +40,7 @@ sub pushd {
 
     my $tainted_dest;
     eval { $tainted_dest   = $target_dir ? abs_path( $target_dir ) : $orig };
+    croak "Can't locate absolute path for $target_dir: $@" if $@;
 
     my $dest;
     if ( $tainted_dest =~ $options->{untaint_pattern} ) {
@@ -48,8 +50,6 @@ sub pushd {
       $dest = $tainted_dest;
     }
 
-    croak "Can't locate directory $target_dir: $@" if $@;
-
     if ($dest ne $orig) {
         chdir $dest or croak "Can't chdir to $dest\: $!";
     }
@@ -102,14 +102,19 @@ sub DESTROY {
     chdir $orig if $orig; # should always be so, but just in case...
     if ( $self->{_tempd} &&
         !$self->{_preserve} ) {
-        eval { rmtree( $self->{_pushd} ) };
-        carp $@ if $@;
+        # don't destroy existing $@ if there is no error.
+        my $err = do {
+            local $@;
+            eval { rmtree( $self->{_pushd} ) };
+            $@;
+        };
+        carp $err if $err;
     }
 }
 
 1;
 
-
+__END__
 
 =pod
 
@@ -119,7 +124,7 @@ File::pushd - change directory temporarily for a limited scope
 
 =head1 VERSION
 
-version 1.001
+version 1.005
 
 =head1 SYNOPSIS
 
@@ -236,40 +241,39 @@ L<File::chdir>
 
 =back
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
 =head2 Bugs / Feature Requests
 
-Please report any bugs or feature requests by email to C<bug-file-pushd at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/Public/Dist/Display.html?Name=File-pushd>. You will be automatically notified of any
-progress on the request by the system.
+Please report any bugs or feature requests through the issue tracker
+at L<https://github.com/dagolden/file-pushd/issues>.
+You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
 
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<http://github.com/dagolden/file-pushd>
+L<https://github.com/dagolden/file-pushd>
 
-  git clone http://github.com/dagolden/file-pushd
+  git clone git://github.com/dagolden/file-pushd.git
 
 =head1 AUTHOR
 
-David A Golden <dagolden@cpan.org>
+David Golden <dagolden@cpan.org>
+
+=head1 CONTRIBUTOR
+
+Diab Jerius <djerius@cfa.harvard.edu>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2011 by David A Golden.
+This software is Copyright (c) 2013 by David A Golden.
 
 This is free software, licensed under:
 
   The Apache License, Version 2.0, January 2004
 
 =cut
-
-
-__END__
-
-
